class Integration < ApplicationRecord
  # ==========================================================
  # Constants
  # ==========================================================
  URL_INPUTS = ["otrs_key_post", "trend_micro_url"]
  
  # ==========================================================
  # Validations
  # ==========================================================
  # URL inputs
  validates :value, format: { with: /\Ahttps?:\/\/[^\s$.?#].[^\s]*\z/i, message: I18n.t("integrations.common.valid_url") }, if: -> { URL_INPUTS.include?(name) }
  
  # DSM Trend Micro API key
  validates :value, format: { with: /\A[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}:.{43}=\z/, message: I18n.t("integrations.common.valid_url") }, if: -> { ["trend_micro_api_key"].include?(name) }

  def self.glpi_params_present?
    params_to_check = %w[
      glpi_api_token
      glpi_api_url
      glpi_app_token
      glpi_update_periodicity
      glpi_update_time
    ]
  
    params_to_check.all? do |param|
      where("value IS NOT NULL AND value != '' AND name = ?", param).exists?
    end
  end 
end
